Documentation
¶
Index ¶
- func GetBool(v *bool) bool
- func GetInt32(v *int32) int32
- func GetInt64(v *int64) int64
- func GetString(s *string) string
- func GetUint32(v *uint32) uint32
- func ToBoolPtr(v bool) *bool
- func ToBoolPtrIfNotFalse(v bool) *bool
- func ToInt32Ptr(v int32) *int32
- func ToInt32PtrIfNotZero(v int32) *int32
- func ToInt64Ptr(v int64) *int64
- func ToInt64PtrIfNotNil(v int64) *int64
- func ToStringPtr(s string) *string
- func ToStringPtrIfNotEmpty(s string) *string
- func ToUint32Ptr(v uint32) *uint32
- func ToUint32PtrIfNotZero(v uint32) *uint32
- func ToUint64Ptr(v uint64) *uint64
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToBoolPtrIfNotFalse ¶
ToBoolPtrIfNotFalse returns a pointer to the value if it's not false, otherwise returns nil.
func ToInt32PtrIfNotZero ¶
func ToInt64PtrIfNotNil ¶
ToInt64PtrIfNotNil returns a pointer to the int64 value if it's not nil, otherwise returns nil.
func ToStringPtr ¶
ToStringPtr returns a pointer to the string value.
func ToStringPtrIfNotEmpty ¶
ToStringPtrIfNotEmpty returns a pointer to the string value if it's not empty, otherwise returns nil.
func ToUint32PtrIfNotZero ¶
ToUint32PtrIfNotZero returns a pointer to the uint32 value if it's not zero, otherwise returns nil.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.